## 2.9.7 (2021-12-26)

Annotate return type of pygments.plugin.iter_entry_points (#6697)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

pygments: Annotate several generator functions (#6695)

## 2.9.6 (2021-12-21)

pygments.formatters.get_all_formatters yields Formatters (#6636)

## 2.9.5 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 2.9.4 (2021-11-23)

Reduce use of deprecated `typing` aliases (#6358)

## 2.9.3 (2021-10-12)

Add star to all non-0.1 versions (#6146)

